==> guile-2.0.12-x86_64-2.txz: usr/lib64/guile/2.0/ccache/system/vm/program.go <==
GOOF----LE-8-2.0=      ]  4    hI
      ] g  guile	 	g  define-module*	 	 	g  system	g  vm	g  program		 	
g  filenameS	f  system/vm/program.scm	g  importsS	
g  base	g  pmatch	
 	 	g  instruction	 	 	g  objcode	 	 	g  rnrs	g  bytevectors	 	 	g  srfi	g  srfi-1	 	 	g  srfi-26	  	!  	"! 	#g  exportsS	$g  make-program	%g  make-binding	&g  binding:name	'g  binding:boxed?	(g  
binding:index	)g  
binding:start	*g  binding:end	+g  source:addr	,g  source:line	-g  
source:column	.g  source:file	/g  source:line-for-user	0g  program-sources	1g  program-sources-pre-retire	2g  program-source	3g  program-bindings	4g  program-bindings-by-index	5g  program-bindings-for-ip	6g  program-arities	7g  
program-arity	8g  arity:start	9g  	arity:end	:g  
arity:nreq	;g  
arity:nopt	<g  arity:rest?	=g  arity:kw	>g  arity:allow-other-keys?	?g  program-arguments-alist	@g  program-lambda-list	Ag  program-meta	Bg  program-objcode	Cg  program?	Dg  program-objects	Eg  program-module	Fg  program-base	Gg  program-free-variables	Hg  program-num-free-variables	Ig  program-free-variable-ref	Jg  program-free-variable-set!	K$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJ '	Lg  set-current-module	ML 	NL 	Og  load-extension	Pg  
string-append	Qf  	libguile-	Rg  effective-version	Sf  scm_init_programs	Tg  list-ref	Ug  *bytecode-header-len*	Vg  opcode->instruction	Wg  load-program	Xg  instruction-length	Yg  bytecode-instruction-length	Zg  objcode->bytecode	[g  reverse	\g  error	]f  
unexpected	^g  map	_g  cdr	`g  sort!	ag  assv-ref	bg  append!	cg  collapse-locals	df  	bad arity	eg  required	fg  optional	gg  keyword	hg  allow-other-keys?	ig  rest	jg  extents	kg  arglist->arguments-alist	lg  string->symbol	mf  _	ng  length	og  arity->arguments-alist	pg  and=>	qg  arguments-alist->lambda-list	rg  assq-ref	sg  keyword->symbol	tg  car	ug  append	vu 	wu 	xg  optionalS	yg  keyS	zg  unfold	{g  1+	|g  format	}f  #<procedure ~a~a>	~g  procedure-name	f  ~a at ~a:~a:~a g  number->string g  object-address f  <current input> f  <unknown port> f    f    g  string-join g  object->string f   |  g  
write-programC 5  h@1    ]4	
"#K5 4N >  "  G   4Oi4PiQ4Ri5 5S>  "  G        h      ]  C       g  name
		 g  boxed?		 g  index			 g  start			 g  end			  g  filenamef  system/vm/program.scm
	5
		6	 			  g  nameg  make-binding C%RT h   x   ] 
6       p       g  b
			  g  filenamef  system/vm/program.scm
	7
			7	 			  g  nameg  binding:name C&RT       h   z   ] 6       r       g  b
			  g  filenamef  system/vm/program.scm
	8
			8	 			  g  nameg  binding:boxed? C'RT     h   y   ] 	6      q       g  b
		
  g  filenamef  system/vm/program.scm
	9
	
	9	 		
  g  nameg  
binding:index C(RT      h   y   ] 	6      q       g  b
		
  g  filenamef  system/vm/program.scm
	:
	
	:	 		
  g  nameg  
binding:start C)RT      h   w   ] 	6      o       g  b
		
  g  filenamef  system/vm/program.scm
	;
	
	;	 		
  g  nameg  binding:end C*R    h   |   ] C  t       g  source
		  g  filenamef  system/vm/program.scm
	=
		>	 		  g  nameg  source:addr C+R       h   |   ] C t       g  source
		  g  filenamef  system/vm/program.scm
	?
		@	 		  g  nameg  source:file C.R       h   |   ] Ct       g  source
		  g  filenamef  system/vm/program.scm
	A
		B	 		  g  nameg  source:line C,R       h   ~   ] Cv       g  source
		  g  filenamef  system/vm/program.scm
	C
		D	 		  g  nameg  
source:column C-R, h      ]4 5C            g  source
		  g  filenamef  system/vm/program.scm
	I
		J		
	J	 		  g  nameg  source:line-for-user C/R	URUVWX       hh     ]4 5&    	"  645
$  " 	 		 	"  45C      g  bytecode
		h g  ip		h g  idx			h g  inst			h  g  filenamef  system/vm/program.scm
	Q
		R			R		
	S			S	$		S			R			V			U		"	W	1	#	W	
	*	X	1	+	X	
	,	W	
	1	Y	
	9	Y	
	=	U		B	\	.	C	\		F	\	
	M	]	.	N	]		Q	]	
	R	\	
	Y	^	)	Z	^	
	[	\	
	`	a	
	g	U	 		h	  g  nameg  bytecode-instruction-length CYRZB[Y\]0  h     ]I44 55"  n(  6$  P"  6	$  		4	5	"	"	"64 5
"         g  proc
	  g  bv	  g  in		  g  out		  g  ip		  g  v		#  g  vx		2	| g  vy		2	| g  ip		:	p g  next			:	p  
g  filenamef  system/vm/program.scm
	m
		n			n			n			n			o			r		 	t		#	v		#	v		:	x		?	z		C	z	
	H	{	#	Q	{		Y	{		\	|		a	}		p	|		p	x	  	  	 	o	 	o	 	p	 	o	 	   g  nameg  program-sources-pre-retire C1R^_`   h      ] C      {       g  x
		
 g  y		
  g  filenamef  system/vm/program.scm
 		 	)	 	1		 	& 		
	   Ca(b    h     ]!"  n(  4564455$  $4 >  "  G  "45 " " ~      g  locs
		 g  ret		t g  locs			t g  b			t g  t		.	t  g  filenamef  system/vm/program.scm
 
	 		 		 		 		 		 		! 		& 		. 		. 	
	7 		@ 	#	E 		R 		Z 		[ 		f 	)	i 		l 		t 		t 		u 		 	 		  g  nameg  collapse-locals CcR3c       h       ]	4 5$  6C              g  prog
		 g  t			  g  filenamef  system/vm/program.scm
 
	 				 		 	 		  g  nameg  program-bindings-by-index C4R[)*4       h     ]"  m(  6"  I(  "  F"  	"45$  45$  
"  """"4 5"           g  prog
	  g  ip	  g  in			s g  out			s g  binds			b  g  filenamef  system/vm/program.scm
 
	 		 		 		 		 		 		, 	!	2 		2 		3 		8 	(	: 		= 		A 		D 		I 	&	K 		L 		S 		V 		b 		e 		k 		s 		s 		t 		{ 	6  	 	 	  g  nameg  program-bindings-for-ip C5R\d  h8      ] $  $  $  C 6 6          g  a
		5 g  vx		- g  vy			-  g  filenamef  system/vm/program.scm
 
	 		) 	3	- 	,	1 	3	5 	, 		5  g  nameg  arity:start C8R\d h8      ]	 $     $  C 6 6              g  a
		1 g  vy		)  g  filenamef  system/vm/program.scm
 
	 		% 	1	) 	*	- 	1	1 	* 		1  g  nameg  	arity:end C9R h8      ] $  ,  $  $  C
C
C
C        g  a
		7 g  vy		5 g  vy			3  g  filenamef  system/vm/program.scm
 
	 	 		7  g  nameg  
arity:nreq C:R    hP      ] $  >  $  ,$  $  C
C
C
C
C              g  a
		I g  vy		G g  vy			E g  vy		,	C  g  filenamef  system/vm/program.scm
 
	 	 		I  g  nameg  
arity:nopt C;R    h`      ]! $  P  $  >$  ,$  $  CCCCCC            g  a
		[ g  vy		Y g  vy			W g  vy		,	U g  vy		<	S  g  filenamef  system/vm/program.scm
 
	 	 		[  g  nameg  arity:rest? C<R   h     ]A $    $  o$  ]$  K$  9$  '$  (  CCCCCCCCC           g  a
	  g  vy	  g  vy		  g  vy		,  g  vy		<  g  vy		L  g  vx		_  g  vy		_  g  vy		m	~  	g  filenamef  system/vm/program.scm
 
	 		} 	: 	   g  nameg  arity:kw C=R    h   
  ]A $    $  o$  ]$  K$  9$  '$  (  CCCCCCCCC          g  a
	  g  vy	  g  vy		  g  vy		,  g  vy		<  g  vy		L  g  vx		_  g  vy		_  g  vx		m	~  	g  filenamef  system/vm/program.scm
 
	 	 	   g  nameg  arity:allow-other-keys? C>R689      hh   l  ]4 5$  U"  I(  C$  7"  	"45$  45$  C""C"Cd      g  prog
		h g  ip		h g  arities				h g  arities			^  g  filenamef  system/vm/program.scm
 
	 			 		 		 			 		* 		0 		0 		1 		6 	'	8 		; 		? 		B 		G 	)	I 		J 		N 		Q 		] 		^ 		 		h	  g  nameg  
program-arity C7Refghij h   8  ]Q $  x  $  e$  R$  ?$  ,
		
 CCCCCC     0      g  arglist
	  g  vx	  g  vy		  g  vx		 	 g  vy		 	 g  vx		1	} g  vy		1	} g  vx		B	{ g  vy		B	{ g  vx			S	y g  vy	
	S	y  g  filenamef  system/vm/program.scm
 
	 		Y 	 	   g  nameg  arglist->arguments-alist CkRlm    h   k   ]6c       g  i
		  g  filenamef  system/vm/program.scm
 	"	 	>	 	. 		   C^(&   h   t   ]4 54 5C      l       g  x
		  g  filenamef  system/vm/program.scm
 		 		
 	1	 	 		   C58a  h       ]	4L  5$  CL 6    z       g  i
		 g  t		  g  filenamef  system/vm/program.scm
 		 		 		 	 		   Cn=e[fgh>i:;<   h@     - . , 3 #  H44 4555O K"  
$  *4J
5	

	"
$  *4J
5	

	"$  24J
44555

	"d	4
54
545
45	 C454545

	"            g  prog
	: g  arity	: g  make-placeholder		: g  var-by-index		: g  rbinds		.	< g  nreq		B g  req		B g  nopt		B g  opt		B g  rest?		B g  rest			B g  n	
	B  g  filenamef  system/vm/program.scm
 
	 		 		$ 	0	, 		. 		. 		B 		F 		J 		M 	
	N 		W 		b 		t 		x 		| 	  	
  	  	  	  	  	  	
  	   	(  	   	  	
  	
  	  	  	  	  	  	  	  	  	 	 	 	 	* 	 	*  	: 	 0	:	  g  nameg  arity->arguments-alist CoR7o     h0   ,  - . , 3 #  4 5$   6C$      g  prog
		0 g  ip		0 g  arity			0  g  filenamef  system/vm/program.scm
 
	 		 		& 		. 		 		0  g  nameg  program-arguments-alistg  
documentationf  PReturns the signature of the given procedure in the form of an association list. C?Rp?q       h(      - . , 3 #  4 56           g  prog
		$ g  ip		$  g  filenamef  system/vm/program.scm
 
	 			$ 	 		$  g  nameg  program-lambda-listg  
documentationf  MReturns the signature of the given procedure in the form of an argument list. C@Rref^stgiwxy   h   `  ]!4 5$  "  4 5$  "  444 5$  "  554 5$  "  	4	$  	
"  4	$  	"  556X      g  arguments-alist
	  g  t		 g  t	&	8 g  t	K	] g  t	j	| g  req	|  g  opt		|  g  key		|  g  rest		|   	g  filenamef  system/vm/program.scm
 
	 			 	+	 		 	
	 	6	 		$ 	+	& 		& 	
	5 	6	9 	
	> 		C 		I 	9	K 		K 		Z 	C	_ 		a 	
	b 		h 	,	j 		j 		y 	3	| 	  	  	  	  	  	.  	 	 	 	 	)  	 &	   g  nameg  arguments-alist->lambda-list CqRHz      h   b   ] L CZ       g  i
		  g  filenamef  system/vm/program.scm
			 		   CI        h   ^   ]L  6      V       g  t-1794
		
  g  filenamef  system/vm/program.scm
	 		
   C{     h       ]	4 5O  O 
6       g  prog
		  g  count			   g  filenamef  system/vm/program.scm

						 	 		   g  nameg  program-free-variablesg  
documentationf  *Return the list of free variables of PROG. CGR|}~p2|./- 
hP      ]	44L 5	54 5$  "   $  "  4 54	 56            g  s
		K g  t		;  g  filenamef  system/vm/program.scm
			"				/				#			0	#	2	)	8	;	<		C	8	K	 		K   C6P^qo   h   }   ]44L  556    u       g  a
		  g  filenamef  system/vm/program.scm
	'		*		+		*		) 		   C      h     ]
4 5$  "  344 
5 O 5$  "  44 5	54	 5$  "  $  
"  44
4 O 5556         g  prog
	  g  port	  g  t			S g  t		1	P g  arities		Z   g  filenamef  system/vm/program.scm

	
						
			!		1		1	
	@		C		M		T		Z	
	b		e	"	j		n		p		u		y		z		}	"  	" 	 	 
	 	 	  g  nameg  
write-program CRC      g  m
		,  g  filenamef  system/vm/program.scm		
	-	2
	2	2		8	2		9	2	+	A	2		C	3		H	2
9	5
	7
u	8
	9
	:
R	;
	=
	?
	A
	C
`	I
e	M
		Q
$	m
 
 
6 
? 
5 
 
 
C 
 
 
 
c 
$ 
&? 
' 
* 
,
1>
 )	1@
   C6 

==> guile-2.0.13-x86_64-2.txz: usr/lib64/guile/2.0/ccache/system/vm/program.go <==
GOOF----LE-8-2.0=      ]  4    hI
      ] g  guile	 	g  define-module*	 	 	g  system	g  vm	g  program		 	
g  filenameS	f  system/vm/program.scm	g  importsS	
g  base	g  pmatch	
 	 	g  instruction	 	 	g  objcode	 	 	g  rnrs	g  bytevectors	 	 	g  srfi	g  srfi-1	 	 	g  srfi-26	  	!  	"! 	#g  exportsS	$g  make-program	%g  make-binding	&g  binding:name	'g  binding:boxed?	(g  
binding:index	)g  
binding:start	*g  binding:end	+g  source:addr	,g  source:line	-g  
source:column	.g  source:file	/g  source:line-for-user	0g  program-sources	1g  program-sources-pre-retire	2g  program-source	3g  program-bindings	4g  program-bindings-by-index	5g  program-bindings-for-ip	6g  program-arities	7g  
program-arity	8g  arity:start	9g  	arity:end	:g  
arity:nreq	;g  
arity:nopt	<g  arity:rest?	=g  arity:kw	>g  arity:allow-other-keys?	?g  program-arguments-alist	@g  program-lambda-list	Ag  program-meta	Bg  program-objcode	Cg  program?	Dg  program-objects	Eg  program-module	Fg  program-base	Gg  program-free-variables	Hg  program-num-free-variables	Ig  program-free-variable-ref	Jg  program-free-variable-set!	K$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJ '	Lg  set-current-module	ML 	NL 	Og  load-extension	Pg  
string-append	Qf  	libguile-	Rg  effective-version	Sf  scm_init_programs	Tg  list-ref	Ug  *bytecode-header-len*	Vg  opcode->instruction	Wg  load-program	Xg  instruction-length	Yg  bytecode-instruction-length	Zg  objcode->bytecode	[g  reverse	\g  error	]f  
unexpected	^g  map	_g  cdr	`g  sort!	ag  assv-ref	bg  append!	cg  collapse-locals	df  	bad arity	eg  required	fg  optional	gg  keyword	hg  allow-other-keys?	ig  rest	jg  extents	kg  arglist->arguments-alist	lg  string->symbol	mf  _	ng  length	og  arity->arguments-alist	pg  and=>	qg  arguments-alist->lambda-list	rg  assq-ref	sg  keyword->symbol	tg  car	ug  append	vu 	wu 	xg  optionalS	yg  keyS	zg  unfold	{g  1+	|g  format	}f  #<procedure ~a~a>	~g  procedure-name	f  ~a at ~a:~a:~a g  number->string g  object-address f  <current input> f  <unknown port> f    f    g  string-join g  object->string f   |  g  
write-programC 5  h@1    ]4	
"#K5 4N >  "  G   4Oi4PiQ4Ri5 5S>  "  G        h      ]  C       g  name
		 g  boxed?		 g  index			 g  start			 g  end			  g  filenamef  system/vm/program.scm
	5
		6	 			  g  nameg  make-binding C%RT h   x   ] 
6       p       g  b
			  g  filenamef  system/vm/program.scm
	7
			7	 			  g  nameg  binding:name C&RT       h   z   ] 6       r       g  b
			  g  filenamef  system/vm/program.scm
	8
			8	 			  g  nameg  binding:boxed? C'RT     h   y   ] 	6      q       g  b
		
  g  filenamef  system/vm/program.scm
	9
	
	9	 		
  g  nameg  
binding:index C(RT      h   y   ] 	6      q       g  b
		
  g  filenamef  system/vm/program.scm
	:
	
	:	 		
  g  nameg  
binding:start C)RT      h   w   ] 	6      o       g  b
		
  g  filenamef  system/vm/program.scm
	;
	
	;	 		
  g  nameg  binding:end C*R    h   |   ] C  t       g  source
		  g  filenamef  system/vm/program.scm
	=
		>	 		  g  nameg  source:addr C+R       h   |   ] C t       g  source
		  g  filenamef  system/vm/program.scm
	?
		@	 		  g  nameg  source:file C.R       h   |   ] Ct       g  source
		  g  filenamef  system/vm/program.scm
	A
		B	 		  g  nameg  source:line C,R       h   ~   ] Cv       g  source
		  g  filenamef  system/vm/program.scm
	C
		D	 		  g  nameg  
source:column C-R, h      ]4 5C            g  source
		  g  filenamef  system/vm/program.scm
	I
		J		
	J	 		  g  nameg  source:line-for-user C/R	URUVWX       hh     ]4 5&    	"  645
$  " 	 		 	"  45C      g  bytecode
		h g  ip		h g  idx			h g  inst			h  g  filenamef  system/vm/program.scm
	Q
		R			R		
	S			S	$		S			R			V			U		"	W	1	#	W	
	*	X	1	+	X	
	,	W	
	1	Y	
	9	Y	
	=	U		B	\	.	C	\		F	\	
	M	]	.	N	]		Q	]	
	R	\	
	Y	^	)	Z	^	
	[	\	
	`	a	
	g	U	 		h	  g  nameg  bytecode-instruction-length CYRZB[Y\]0  h     ]I44 55"  n(  6$  P"  6	$  		4	5	"	"	"64 5
"         g  proc
	  g  bv	  g  in		  g  out		  g  ip		  g  v		#  g  vx		2	| g  vy		2	| g  ip		:	p g  next			:	p  
g  filenamef  system/vm/program.scm
	m
		n			n			n			n			o			r		 	t		#	v		#	v		:	x		?	z		C	z	
	H	{	#	Q	{		Y	{		\	|		a	}		p	|		p	x	  	  	 	o	 	o	 	p	 	o	 	   g  nameg  program-sources-pre-retire C1R^_`   h      ] C      {       g  x
		
 g  y		
  g  filenamef  system/vm/program.scm
 		 	)	 	1		 	& 		
	   Ca(b    h     ]!"  n(  4564455$  $4 >  "  G  "45 " " ~      g  locs
		 g  ret		t g  locs			t g  b			t g  t		.	t  g  filenamef  system/vm/program.scm
 
	 		 		 		 		 		 		! 		& 		. 		. 	
	7 		@ 	#	E 		R 		Z 		[ 		f 	)	i 		l 		t 		t 		u 		 	 		  g  nameg  collapse-locals CcR3c       h       ]	4 5$  6C              g  prog
		 g  t			  g  filenamef  system/vm/program.scm
 
	 				 		 	 		  g  nameg  program-bindings-by-index C4R[)*4       h     ]"  m(  6"  I(  "  F"  	"45$  45$  
"  """"4 5"           g  prog
	  g  ip	  g  in			s g  out			s g  binds			b  g  filenamef  system/vm/program.scm
 
	 		 		 		 		 		 		, 	!	2 		2 		3 		8 	(	: 		= 		A 		D 		I 	&	K 		L 		S 		V 		b 		e 		k 		s 		s 		t 		{ 	6  	 	 	  g  nameg  program-bindings-for-ip C5R\d  h8      ] $  $  $  C 6 6          g  a
		5 g  vx		- g  vy			-  g  filenamef  system/vm/program.scm
 
	 		) 	3	- 	,	1 	3	5 	, 		5  g  nameg  arity:start C8R\d h8      ]	 $     $  C 6 6              g  a
		1 g  vy		)  g  filenamef  system/vm/program.scm
 
	 		% 	1	) 	*	- 	1	1 	* 		1  g  nameg  	arity:end C9R h8      ] $  ,  $  $  C
C
C
C        g  a
		7 g  vy		5 g  vy			3  g  filenamef  system/vm/program.scm
 
	 	 		7  g  nameg  
arity:nreq C:R    hP      ] $  >  $  ,$  $  C
C
C
C
C              g  a
		I g  vy		G g  vy			E g  vy		,	C  g  filenamef  system/vm/program.scm
 
	 	 		I  g  nameg  
arity:nopt C;R    h`      ]! $  P  $  >$  ,$  $  CCCCCC            g  a
		[ g  vy		Y g  vy			W g  vy		,	U g  vy		<	S  g  filenamef  system/vm/program.scm
 
	 	 		[  g  nameg  arity:rest? C<R   h     ]A $    $  o$  ]$  K$  9$  '$  (  CCCCCCCCC           g  a
	  g  vy	  g  vy		  g  vy		,  g  vy		<  g  vy		L  g  vx		_  g  vy		_  g  vy		m	~  	g  filenamef  system/vm/program.scm
 
	 		} 	: 	   g  nameg  arity:kw C=R    h   
  ]A $    $  o$  ]$  K$  9$  '$  (  CCCCCCCCC          g  a
	  g  vy	  g  vy		  g  vy		,  g  vy		<  g  vy		L  g  vx		_  g  vy		_  g  vx		m	~  	g  filenamef  system/vm/program.scm
 
	 	 	   g  nameg  arity:allow-other-keys? C>R689      hh   l  ]4 5$  U"  I(  C$  7"  	"45$  45$  C""C"Cd      g  prog
		h g  ip		h g  arities				h g  arities			^  g  filenamef  system/vm/program.scm
 
	 			 		 		 			 		* 		0 		0 		1 		6 	'	8 		; 		? 		B 		G 	)	I 		J 		N 		Q 		] 		^ 		 		h	  g  nameg  
program-arity C7Refghij h   8  ]Q $  x  $  e$  R$  ?$  ,
		
 CCCCCC     0      g  arglist
	  g  vx	  g  vy		  g  vx		 	 g  vy		 	 g  vx		1	} g  vy		1	} g  vx		B	{ g  vy		B	{ g  vx			S	y g  vy	
	S	y  g  filenamef  system/vm/program.scm
 
	 		Y 	 	   g  nameg  arglist->arguments-alist CkRlm    h   k   ]6c       g  i
		  g  filenamef  system/vm/program.scm
 	"	 	>	 	. 		   C^(&   h   t   ]4 54 5C      l       g  x
		  g  filenamef  system/vm/program.scm
 		 		
 	1	 	 		   C58a  h       ]	4L  5$  CL 6    z       g  i
		 g  t		  g  filenamef  system/vm/program.scm
 		 		 		 	 		   Cn=e[fgh>i:;<   h@     - . , 3 #  H44 4555O K"  
$  *4J
5	

	"
$  *4J
5	

	"$  24J
44555

	"d	4
54
545
45	 C454545

	"            g  prog
	: g  arity	: g  make-placeholder		: g  var-by-index		: g  rbinds		.	< g  nreq		B g  req		B g  nopt		B g  opt		B g  rest?		B g  rest			B g  n	
	B  g  filenamef  system/vm/program.scm
 
	 		 		$ 	0	, 		. 		. 		B 		F 		J 		M 	
	N 		W 		b 		t 		x 		| 	  	
  	  	  	  	  	  	
  	   	(  	   	  	
  	
  	  	  	  	  	  	  	  	  	 	 	 	 	* 	 	*  	: 	 0	:	  g  nameg  arity->arguments-alist CoR7o     h0   ,  - . , 3 #  4 5$   6C$      g  prog
		0 g  ip		0 g  arity			0  g  filenamef  system/vm/program.scm
 
	 		 		& 		. 		 		0  g  nameg  program-arguments-alistg  
documentationf  PReturns the signature of the given procedure in the form of an association list. C?Rp?q       h(      - . , 3 #  4 56           g  prog
		$ g  ip		$  g  filenamef  system/vm/program.scm
 
	 			$ 	 		$  g  nameg  program-lambda-listg  
documentationf  MReturns the signature of the given procedure in the form of an argument list. C@Rref^stgiwxy   h   `  ]!4 5$  "  4 5$  "  444 5$  "  554 5$  "  	4	$  	
"  4	$  	"  556X      g  arguments-alist
	  g  t		 g  t	&	8 g  t	K	] g  t	j	| g  req	|  g  opt		|  g  key		|  g  rest		|   	g  filenamef  system/vm/program.scm
 
	 			 	+	 		 	
	 	6	 		$ 	+	& 		& 	
	5 	6	9 	
	> 		C 		I 	9	K 		K 		Z 	C	_ 		a 	
	b 		h 	,	j 		j 		y 	3	| 	  	  	  	  	  	.  	 	 	 	 	)  	 &	   g  nameg  arguments-alist->lambda-list CqRHz      h   b   ] L CZ       g  i
		  g  filenamef  system/vm/program.scm
			 		   CI        h   _   ]L  6      W       g  t-15811
		
  g  filenamef  system/vm/program.scm
	 		
   C{    h       ]	4 5O  O 
6       g  prog
		  g  count			   g  filenamef  system/vm/program.scm

						 	 		   g  nameg  program-free-variablesg  
documentationf  *Return the list of free variables of PROG. CGR|}~p2|./- 
hP      ]	44L 5	54 5$  "   $  "  4 54	 56            g  s
		K g  t		;  g  filenamef  system/vm/program.scm
			"				/				#			0	#	2	)	8	;	<		C	8	K	 		K   C6P^qo   h   }   ]44L  556    u       g  a
		  g  filenamef  system/vm/program.scm
	'		*		+		*		) 		   C      h     ]
4 5$  "  344 
5 O 5$  "  44 5	54	 5$  "  $  
"  44
4 O 5556         g  prog
	  g  port	  g  t			S g  t		1	P g  arities		Z   g  filenamef  system/vm/program.scm

	
						
			!		1		1	
	@		C		M		T		Z	
	b		e	"	j		n		p		u		y		z		}	"  	" 	 	 
	 	 	  g  nameg  
write-program CRC      g  m
		,  g  filenamef  system/vm/program.scm		
	-	2
	2	2		8	2		9	2	+	A	2		C	3		H	2
9	5
	7
u	8
	9
	:
R	;
	=
	?
	A
	C
`	I
e	M
		Q
$	m
 
 
6 
? 
5 
 
 
C 
 
 
 
c 
$ 
&? 
' 
* 
,
1>
 )	1@
   C6 
